@@ -1,11 +1,8 @@
-from .uimodels.collection import CollectionUiManager
-from .uimodels.provider import ProviderUiManager
+from .provider_ui import ProviderUiManager
 from .uimodels.my_music import MyMusicUiManager
 from .uimodels.playlist import PlaylistUiManager
 
-
 __all__ = (
-    'CollectionUiManager',
     'ProviderUiManager',
     'MyMusicUiManager',
     'PlaylistUiManager',
