@@ -4,13 +4,14 @@ from PyQt5.QtWidgets import QSizePolicy, QSplitter, QVBoxLayout
 from feeluown.gui.widgets.separator import Separator
 from feeluown.gui.widgets.settings import SettingsDialog
 from feeluown.gui.widgets.messageline import MessageLine
-from feeluown.gui.widgets.mpv import MpvOpenGLWidget
+from feeluown.gui.widgets.mpv_ import MpvOpenGLWidget
 
 from feeluown.gui.uimain.lyric import LyricWindow
 from feeluown.gui.uimain.sidebar import LeftPanel
 from feeluown.gui.uimain.page_view import RightPanel
 from feeluown.gui.uimain.player_bar import TopPanel
 from feeluown.gui.uimain.playlist_overlay import PlaylistOverlay
+from feeluown.gui.uimain.nowplaying_overlay import NowplayingOverlay
 
 logger = logging.getLogger(__name__)
 
@@ -26,8 +27,18 @@ class Ui:
         self._splitter = QSplitter(app)
 
         # Create widgets that don't rely on other widgets first.
+        try:
+            from feeluown.gui.uimain.ai_chat import create_aichat_overlay
+        except ImportError as e:
+            logger.warning(f'AIChatOverlay is not available: {e}')
+            self.ai_chat_overlay = None
+        else:
+            self.ai_chat_overlay = create_aichat_overlay(app, parent=app)
+            self.ai_chat_overlay.hide()
         self.lyric_window = LyricWindow(self._app)
         self.lyric_window.hide()
+        self.playlist_overlay = PlaylistOverlay(app, parent=app)
+        self.nowplaying_overlay = NowplayingOverlay(app, parent=app)
 
         # NOTE: 以位置命名的部件应该只用来组织界面布局，不要
         # 给其添加任何功能性的函数
@@ -38,7 +49,6 @@ class Ui:
         self.page_view = self.right_panel = RightPanel(self._app, self._splitter)
         self.toolbar = self.bottom_panel = self.right_panel.bottom_panel
         self.mpv_widget = MpvOpenGLWidget(self._app)
-        self.playlist_overlay = PlaylistOverlay(app, parent=app)
 
         # alias
         self.magicbox = self.bottom_panel.magicbox
@@ -49,10 +59,8 @@ class Ui:
         self.songs_table = self.table_container.songs_table
         self.back_btn = self.bottom_panel.back_btn
         self.forward_btn = self.bottom_panel.forward_btn
-        self.toggle_video_btn = self.pc_panel.toggle_video_btn
 
-        self.toolbar.settings_btn.clicked.connect(
-            self._open_settings_dialog)
+        self.toolbar.settings_btn.clicked.connect(self._open_settings_dialog)
 
         self._setup_ui()
 
@@ -64,6 +72,7 @@ class Ui:
         self._splitter.addWidget(self.right_panel)
         self._message_line.hide()
         self.playlist_overlay.hide()
+        self.nowplaying_overlay.hide()
 
         self.right_panel.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
 
