@@ -1,16 +1,16 @@
-from PyQt5.QtCore import Qt, QRect, QEvent, QModelIndex, QItemSelectionModel
+from PyQt5.QtCore import Qt, QRect, QEvent
 from PyQt5.QtWidgets import (
-    QWidget, QStackedLayout, QVBoxLayout, QHBoxLayout, QMenu,
-    QApplication, QShortcut, QAbstractItemView
+    QWidget, QStackedLayout, QVBoxLayout, QHBoxLayout,
+    QApplication,
 )
 from PyQt5.QtGui import (
-    QColor, QLinearGradient, QPalette, QPainter, QKeySequence,
+    QColor, QLinearGradient, QPalette, QPainter,
 )
 
-from feeluown.player import PlaybackMode
-from feeluown.gui.helpers import fetch_cover_wrapper
+from feeluown.player import PlaybackMode, SongsRadio, AIRadio, AI_RADIO_SUPPORTED
+from feeluown.gui.helpers import fetch_cover_wrapper, esc_hide_widget
+from feeluown.gui.components.player_playlist import PlayerPlaylistView
 from feeluown.gui.widgets.textbtn import TextButton
-from feeluown.gui.components import SongMenuInitializer
 from feeluown.gui.widgets.tabbar import TabBar
 from feeluown.gui.widgets.song_minicard_list import (
     SongMiniCardListView,
@@ -45,16 +45,19 @@ class PlaylistOverlay(QWidget):
         self._clear_playlist_btn = TextButton('清空播放队列')
         self._playback_mode_switch = PlaybackModeSwitch(app)
         self._goto_current_song_btn = TextButton('跳转到当前歌曲')
+        self._songs_radio_btn = TextButton('自动续歌')
+        self._ai_radio_btn = TextButton('AI电台')
         # Please update the list when you add new buttons.
-        self._btns = [self._clear_playlist_btn,
-                      self._playback_mode_switch,
-                      self._goto_current_song_btn]
+        self._btns = [
+            self._clear_playlist_btn,
+            self._playback_mode_switch,
+            self._goto_current_song_btn,
+            self._songs_radio_btn,
+        ]
         self._stacked_layout = QStackedLayout()
         self._shadow_width = 15
-        self._player_playlist_model = PlayerPlaylistModel(
-            self._app.playlist,
-            fetch_cover_wrapper(self._app),
-        )
+        self._view_options = dict(row_height=60, no_scroll_v=False)
+        self._player_playlist_view = PlayerPlaylistView(self._app, **self._view_options)
 
         # AutoFillBackground should be disabled for PlaylistOverlay so that shadow
         # effects can be simulated. AutoFillBackground should be enabled for tabbar.
@@ -62,34 +65,53 @@ class PlaylistOverlay(QWidget):
 
         self._clear_playlist_btn.clicked.connect(self._app.playlist.clear)
         self._goto_current_song_btn.clicked.connect(self.goto_current_song)
-        QShortcut(QKeySequence.Cancel, self).activated.connect(self.hide)
+        self._songs_radio_btn.clicked.connect(self.enter_songs_radio)
+        self._ai_radio_btn.clicked.connect(self.enter_ai_radio)
+        esc_hide_widget(self)
         q_app = QApplication.instance()
         assert q_app is not None  # make type checker happy.
         # type ignore: q_app has focusChanged signal, but type checker can't find it.
         q_app.focusChanged.connect(self.on_focus_changed)  # type: ignore
         self._app.installEventFilter(self)
         self._tabbar.currentChanged.connect(self.show_tab)
+
+        if (
+            AI_RADIO_SUPPORTED is True
+            and self._app.config.OPENAI_API_KEY
+            and self._app.config.OPENAI_MODEL
+            and self._app.config.OPENAI_API_BASEURL
+        ):
+            self._ai_radio_btn.clicked.connect(self.enter_ai_radio)
+        else:
+            self._ai_radio_btn.setDisabled(True)
         self.setup_ui()
 
     def setup_ui(self):
         self._layout = QVBoxLayout(self)
         self._btn_layout = QHBoxLayout()
+        self._btn_layout2 = QHBoxLayout()
         self._layout.setContentsMargins(self._shadow_width, 0, 0, 0)
         self._layout.setSpacing(0)
         self._btn_layout.setContentsMargins(7, 7, 7, 7)
         self._btn_layout.setSpacing(7)
+        self._btn_layout2.setContentsMargins(7, 0, 7, 7)
+        self._btn_layout2.setSpacing(7)
 
         self._tabbar.setDocumentMode(True)
         self._tabbar.addTab('播放列表')
         self._tabbar.addTab('最近播放')
         self._layout.addWidget(self._tabbar)
         self._layout.addLayout(self._btn_layout)
+        self._layout.addLayout(self._btn_layout2)
         self._layout.addLayout(self._stacked_layout)
 
         self._btn_layout.addWidget(self._clear_playlist_btn)
         self._btn_layout.addWidget(self._playback_mode_switch)
         self._btn_layout.addWidget(self._goto_current_song_btn)
+        self._btn_layout2.addWidget(self._songs_radio_btn)
+        self._btn_layout2.addWidget(self._ai_radio_btn)
         self._btn_layout.addStretch(0)
+        self._btn_layout2.addStretch(0)
 
     def on_focus_changed(self, _, new):
         """
@@ -107,24 +129,39 @@ class PlaylistOverlay(QWidget):
         assert isinstance(view, PlayerPlaylistView)
         view.scroll_to_current_song()
 
+    def enter_songs_radio(self):
+        songs = self._app.playlist.list()
+        if not songs:
+            self._app.show_msg('播放队列为空，不能激活“自动续歌”功能')
+        else:
+            radio = SongsRadio(self._app, songs)
+            self._app.fm.activate(radio.fetch_songs_func, reset=False)
+            self._app.show_msg('“自动续歌”功能已激活')
+
+    def enter_ai_radio(self):
+        if self._app.playlist.list():
+            radio = AIRadio(self._app)
+            self._app.fm.activate(radio.fetch_songs_func, reset=False)
+            self._app.show_msg('已经进入 AI 电台模式 ~')
+        else:
+            self._app.show_msg('播放列表为空，暂时不能开启 AI 电台')
+
     def show_tab(self, index):
         if not self.isVisible():
             return
 
-        view_options = dict(row_height=60, no_scroll_v=False)
         if index == 0:
             self._show_btns()
-            view: SongMiniCardListView = PlayerPlaylistView(self._app, **view_options)
-            view.setModel(self._player_playlist_model)
+            view = self._player_playlist_view
         else:
             self._hide_btns()
             model = SongMiniCardListModel(
                 create_reader(self._app.recently_played.list_songs()),
                 fetch_cover_wrapper(self._app)
             )
-            view = SongMiniCardListView(**view_options)
+            view = SongMiniCardListView(**self._view_options)
             view.setModel(model)
-
+            view.play_song_needed.connect(self._app.playlist.play_model)
         delegate = SongMiniCardListDelegate(
             view,
             card_min_width=self.width() - self.width()//6,
@@ -133,7 +170,6 @@ class PlaylistOverlay(QWidget):
             card_right_spacing=10,
         )
         view.setItemDelegate(delegate)
-        view.play_song_needed.connect(self._app.playlist.play_model)
         self._stacked_layout.addWidget(view)
         self._stacked_layout.setCurrentWidget(view)
 
@@ -182,71 +218,6 @@ class PlaylistOverlay(QWidget):
         return False
 
 
-class PlayerPlaylistModel(SongMiniCardListModel):
-    def __init__(self, playlist, *args, **kwargs):
-        reader = create_reader(playlist.list())
-        super().__init__(reader, *args, **kwargs)
-
-        self._playlist = playlist
-        self._playlist.songs_added.connect(self.on_songs_added)
-        self._playlist.songs_removed.connect(self.on_songs_removed)
-
-    def flags(self, index):
-        flags = super().flags(index)
-        song = index.data(Qt.UserRole)[0]
-        if self._playlist.is_bad(song):
-            # Disable bad song.
-            flags &= ~Qt.ItemIsEnabled
-        return flags
-
-    def on_songs_added(self, index, count):
-        self.beginInsertRows(QModelIndex(), index, index+count-1)
-        # Insert from tail to front.
-        while count > 0:
-            self._items.insert(index, self._playlist[index+count-1])
-            count -= 1
-        self.endInsertRows()
-
-    def on_songs_removed(self, index, count):
-        self.beginRemoveRows(QModelIndex(), index, index+count-1)
-        while count > 0:
-            self._items.pop(index + count - 1)
-            count -= 1
-        self.endRemoveRows()
-
-
-class PlayerPlaylistView(SongMiniCardListView):
-    def __init__(self, app, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self._app = app
-
-    def contextMenuEvent(self, e):
-        index = self.indexAt(e.pos())
-        if not index.isValid():
-            return
-
-        song = index.data(Qt.UserRole)[0]
-        menu = QMenu()
-        action = menu.addAction('从播放队列中移除')
-        menu.addSeparator()
-        SongMenuInitializer(self._app, song).apply(menu)
-
-        action.triggered.connect(lambda: self._app.playlist.remove(song))
-        menu.exec_(e.globalPos())
-
-    def scroll_to_current_song(self):
-        """Scroll to the current song, and select it to highlight it."""
-        current_song = self._app.playlist.current_song
-        songs = self._app.playlist.list()
-        if current_song is not None:
-            model = self.model()
-            row = songs.index(current_song)
-            index = model.index(row, 0)
-            # In order to highlight the current song.
-            self.selectionModel().select(index, QItemSelectionModel.SelectCurrent)
-            self.scrollTo(index, QAbstractItemView.PositionAtCenter)
-
-
 class PlaybackModeSwitch(TextButton):
     def __init__(self, app, *args, **kwargs):
         super().__init__(*args, **kwargs)
